Module database

Module database 

FFI Database bindings

Structs

UniFfiTraitVtableWalletDatabase

Enums

WalletDbBackend
FFI-safe database type enum
WalletStore
Unified wallet storage: either a built-in Rust backend or a custom foreign-language implementation of the WalletDatabase callback interface.

Traits

WalletDatabase
FFI-compatible wallet database trait with all read and write operations This trait mirrors the CDK WalletDatabase trait structure

Functions

create_cdk_database_from_ffi
Helper function to create a CDK database from the FFI trait
create_wallet_db
Factory helpers returning a CDK wallet database behind the FFI trait
custom_wallet_store
Create a wallet store backed by a custom foreign-language database implementation.
resolve_wallet_store
Resolve a WalletStore into an Arc<dyn WalletDatabase>.
sqlite_wallet_store
Create a SQLite-backed wallet store.
uniffi_cdk_ffi_fn_init_callback_vtable_walletdatabase