pub struct PaymentRequest { /* private fields */ }Expand description
NUT-18 Payment Request
A payment request that can be shared to request Cashu tokens.
Encoded as a string with the creqA prefix.
Implementations
Sourceimpl PaymentRequest
impl PaymentRequest
Sourcepub fn from_string(encoded: String) -> Result<Arc<Self>, FfiError>
pub fn from_string(encoded: String) -> Result<Arc<Self>, FfiError>
Parse a payment request from its encoded string representation
Sourcepub fn to_string_encoded(&self) -> String
pub fn to_string_encoded(&self) -> String
Encode the payment request to a string
Sourcepub fn to_bech32_string(&self) -> Result<String, FfiError>
pub fn to_bech32_string(&self) -> Result<String, FfiError>
Encode the payment request to a NUT-26 bech32m string (creqB prefix)
Sourcepub fn to_bip321(
&self,
bolt11: Option<String>,
bolt12: Option<String>,
) -> Result<String, FfiError>
pub fn to_bip321( &self, bolt11: Option<String>, bolt12: Option<String>, ) -> Result<String, FfiError>
Convert this payment request to a BIP 321 bitcoin: URI string.
The cashu payment request is encoded as a NUT-26 bech32m CREQB1...
string in the creq= query parameter. Optionally include a BOLT11
invoice (lightning=) and/or BOLT12 offer (lno=) as fallback
payment methods for wallets that don’t support cashu.
val request = PaymentRequest.fromString("CREQB1...")
val uri = request.toBip321(
bolt11 = "lnbc100n1p...",
bolt12 = "lno1qgsq..."
)
// => "bitcoin:?creq=CREQB1...&lightning=lnbc100n1p...&lno=lno1qgsq..."Sourcepub fn payment_id(&self) -> Option<String>
pub fn payment_id(&self) -> Option<String>
Get the payment ID
Sourcepub fn unit(&self) -> Option<CurrencyUnit>
pub fn unit(&self) -> Option<CurrencyUnit>
Get the currency unit
Sourcepub fn single_use(&self) -> Option<bool>
pub fn single_use(&self) -> Option<bool>
Get whether this is a single-use request
Sourcepub fn description(&self) -> Option<String>
pub fn description(&self) -> Option<String>
Get the description
Sourcepub fn transports(&self) -> Vec<Transport>
pub fn transports(&self) -> Vec<Transport>
Get the transports for delivering the payment