MintQuoteCustomResponse

Struct MintQuoteCustomResponse 

pub struct MintQuoteCustomResponse {
    pub quote: String,
    pub request: String,
    pub expiry: Option<u64>,
    pub amount: Option<Amount>,
    pub amount_paid: Amount,
    pub amount_issued: Amount,
    pub unit: Option<CurrencyUnit>,
    pub pubkey: Option<String>,
    pub extra: Option<String>,
}
FFI-compatible MintQuoteCustomResponse

This is a unified response type for custom payment methods that includes extra fields for method-specific data (e.g., ehash share).

Fields

quote: String

Quote ID

request: String

Request string

expiry: Option<u64>

Expiry timestamp (optional)

amount: Option<Amount>

Amount (optional)

amount_paid: Amount

Amount paid

amount_issued: Amount

Amount issued

unit: Option<CurrencyUnit>

Unit (optional)

pubkey: Option<String>

Pubkey (optional)

extra: Option<String>

Extra payment-method-specific fields as JSON string

These fields are flattened into the JSON representation, allowing custom payment methods to include additional data without nesting.