pub struct PreparedSend { /* private fields */ }Expand description
FFI-compatible PreparedSend
This wraps the data from a prepared send operation along with a reference to the wallet. The actual PreparedSend<’a> from cdk has a lifetime parameter that doesn’t work with FFI, so we store the wallet and cached data separately.
Implementations
Sourceimpl PreparedSend
impl PreparedSend
Sourcepub fn new(wallet: Arc<Wallet>, prepared: &PreparedSend<'_>) -> Self
pub fn new(wallet: Arc<Wallet>, prepared: &PreparedSend<'_>) -> Self
Create a new FFI PreparedSend from a cdk::wallet::PreparedSend and wallet