FFI Database bindings
Structs
Enums
- Wallet
DbBackend - FFI-safe database type enum
- Wallet
Store - Unified wallet storage: either a built-in Rust backend or a custom
foreign-language implementation of the
WalletDatabasecallback interface.
Traits
- Wallet
Database - FFI-compatible wallet database trait with all read and write operations This trait mirrors the CDK WalletDatabase trait structure
Functions
- create_
cdk_ database_ from_ ffi - Helper function to create a CDK database from the FFI trait
- create_
wallet_ db - Factory helpers returning a CDK wallet database behind the FFI trait
- custom_
wallet_ store - Create a wallet store backed by a custom foreign-language database implementation.
- resolve_
wallet_ store - Resolve a
WalletStoreinto anArc<dyn WalletDatabase>. - sqlite_
wallet_ store - Create a SQLite-backed wallet store.
- uniffi_
cdk_ ffi_ fn_ init_ callback_ vtable_ walletdatabase